@@ -1,4 +1,4 @@
-# $Id: Alias.pm 41573 2014-05-20 13:19:11Z wsl $
+# $Id: Alias.pm 42214 2014-09-11 11:10:43Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/lib/UvT/Kiki/Database/Alias.pm $
 
 use utf8;
@@ -17,7 +17,7 @@ use constant type => 'alias';
 field db;
 
 field id;
-field name;
+field localpart;
 field domain;
 field addressbook;
 field destinations => sub {
@@ -33,63 +33,55 @@ field original => sub {
 	return $clone;
 };
 
-sub names {
-	return [$self];
-}
-
 sub clone {
 	my $class = ref $self;
-	my $clone = $class->new(
+	return $class->new(
 		id => $self->id,
-		name => $self->name,
+		localpart => $self->localpart,
 		domain => $self->domain,
 		addressbook => $self->addressbook,
+		destinations => $self->destinations,
+		referrers => $self->referrers,
 	);
-	if(my $dst = $self->destinations) {
-		$clone->destinations($dst);
-	}
-	if(my $ref = $self->referrers) {
-		$clone->referrers($ref);
-	}
-	return $clone;
 }
 
 sub full {
-	return $self->name . '@' . $self->domain->name;
+	return $self->localpart . '@' . $self->domain->name;
 }
 
 sub unique {
 	my $db = $self->db;
 	my $a = $db->fetch_alias($self->full);
 	return 1 unless $a;
+	return 0 unless $a->can('id');
 	my $id = $self->id;
 	return 1 if defined $id && $id == $a->id;
 	return 0;
 }
 
-sub update_name {
-	my $newname = shift;
-	return [error => 'empty-name'] if $newname eq '';
+sub update_localpart {
+	my $newlocalpart = shift;
+	return [error => 'empty-localpart'] if $newlocalpart eq '';
 	if(my $original = $self->original) {
-		my $oldname = $original->name;
+		my $oldlocalpart = $original->localpart;
 
-		return [ok => 'unchanged', $newname]
-			if $newname eq $oldname;
+		return [ok => 'unchanged', $newlocalpart]
+			if $newlocalpart eq $oldlocalpart;
 
-		if(lc($newname) eq lc($oldname)) {
-			$self->name($newname);
-			return [ok => 'case', $newname];
+		if(lc($newlocalpart) eq lc($oldlocalpart)) {
+			$self->localpart($newlocalpart);
+			return [ok => 'case', $newlocalpart];
 		}
 	}
 
-	return [error => 'malformed']
-		if $newname !~ /^[a-z0-9_]+(?:[.-][a-z0-9_]+)*$/i;
+	return [error => 'malformed-localpart']
+		if $newlocalpart !~ /^[a-z0-9_]+(?:[.-][a-z0-9_]+)*$/ai;
 
-	return [error => 'too-long']
-		if length($newname) > 64;
+	return [error => 'localpart-too-long']
+		if length($newlocalpart) > 64;
 
-	$self->name($newname);
-	return [ok => 'changed', $newname];
+	$self->localpart($newlocalpart);
+	return [ok => 'changed', $newlocalpart];
 }
 
 sub update_domain {
@@ -97,7 +89,7 @@ sub update_domain {
 	return [error => 'empty-domain'] if $newdomain eq '';
 
 	$newdomain = $self->db->domain_by_name($newdomain);
-	return [error => 'unknown'] unless $newdomain;
+	return [error => 'unknown-domain'] unless $newdomain;
 
 	if(my $original = $self->original) {
 		my $olddomain = $original->domain;
@@ -139,14 +131,14 @@ sub update_destinations {
 	foreach(@$destinations) {
 		if($_ eq '') {
 			# leeg
-			push @notes, [ok => 'empty', ''];
+			push @notes, [ok => 'empty', s/^\s*//ra];
 			next;
 		} elsif(/^\d{6}$/) {
 			# anr, check of-ie bestaat
-			my $a = $db->person_for_anr($_);
-			if($a) {
-				my $addr = $a->full;
-				$uniq{$addr} = $a;
+			my $p = $db->person_for_anr($_);
+			if($p) {
+				my $addr = $p->full;
+				$uniq{$addr} = $p;
 				push @notes, [ok => 'anr', $addr];
 			} else {
 				$fail = 1;
@@ -159,14 +151,18 @@ sub update_destinations {
 				push @notes, [error => 'multiple'];
 				next;
 			}
+
 			unless(defined $x && $x->original eq $_) {
 				$fail = 1;
 				push @notes, [error => 'invalid-address'];
 				next;
 			}
 
-			my $a = $db->fetch_alias($x->address);
-			if($a) {
+			if(my $p = $db->person_for_mailbox($x->address)) {
+				my $addr = $p->full;
+				$uniq{$addr} = $p;
+				push @notes, [ok => 'person', $addr];
+			} elsif(my $a = $db->fetch_alias($x->address)) {
 				my $addr = $a->full;
 				$uniq{$addr} = $a;
 				push @notes, [ok => $a->type, $addr];
@@ -187,13 +183,13 @@ sub update_destinations {
 			}
 		} else {
 			# localpart, check of-ie bestaat en uniek is
-			my $res = $db->fetch_alias_by_localname($_);
+			my $res = $db->fetch_alias_by_localpart($_);
 			if(@$res < 1) {
 				$fail = 1;
 				push @notes, [error => 'unknown-alias'];
 			} elsif(@$res > 1) {
 				$fail = 1;
-				push @notes, [error => 'not-unique'];
+				push @notes, [error => 'localpart-not-unique'];
 			} else {
 				my ($a) = @$res;
 				my $addr = $a->full;
@@ -223,6 +219,10 @@ sub remove {
 	}
 }
 
+sub expand {
+	$self->destinations;
+}
+
 sub store {
 	if($self->id) {
 		$self->db->update_alias($self);
@@ -232,7 +232,9 @@ sub store {
 }
 
 sub toString {
-	return $self->full . ': ' . join(', ', sort { lc($a) cmp lc($b) } map { $_->full } @{$self->destinations});
+	return $self->full . ": "
+		. join(', ', sort { lc($a) cmp lc($b) } map { $_->full } @{$self->destinations})
+		. ($self->addressbook ? " (in address book)" : " (not in address book)");
 }
 
 sub json_boolean() {
@@ -242,16 +244,15 @@ sub json_boolean() {
 }
 
 sub TO_JSON {
-	my %res = (type => $self->type);
-	$res{name} = $self->name
-		if $self->name_isset;
-	$res{domain} = $self->domain->name
-		if $self->domain_isset;
-	$res{addressbook} = json_boolean($self->addressbook)
-		if $self->addressbook_isset;
-	$res{destinations} = $self->destinations
-		if $self->destinations_isset;
-	$res{referrers} = $self->referrers
-		if $self->referrers_isset;
-	return \%res;
+	my $destinations = $self->destinations;
+	my %destinations;
+	foreach my $destination (@$destinations) {
+		push @{$destinations{$destination->type}}, $destination->full;
+	}
+	return {
+#		type => $self->type,
+		address => $self->full,
+		destinations => \%destinations,
+		addressbook => json_boolean($self->addressbook),
+	};
 }
