@@ -1,4 +1,4 @@
-# $Id: Request.pm 37660 2012-08-28 09:49:55Z wsl $
+# $Id: Request.pm 42205 2014-09-10 15:00:35Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/lib/UvT/Kiki/WS/Alias/Delete/Request.pm $
 
 use utf8;
@@ -18,9 +18,10 @@ field new_alias => sub {
 
 	if($self->nonce) {
 		my $name = $alias->full;
+		my $what = $self->is_robot ? "Robot" : "User";
 		my $who = $self->login;
 		my $old = $alias->toString;
-		my $text = "User $who deleted alias:\n\told: $old\n";
+		my $text = "$what $who deleted alias:\n\told: $old\n";
 
 		my $note = $alias->remove;
 		$self->note($note);
